==> nisje-wp-plugin-news-7.1.1.zip: news/post-types/post-type-news.php <==
<?php
/**
 * Setup News Post Type
 *
 * @package Nisje
 */

defined( 'ABSPATH' ) || die( 'Shame on you' );

$cap            = nisje_get_setting( 'capability_key', 'news' );
$post_type_name = nisje_get_setting( 'post_type_name', 'news' );
$rest_endpoint  = nisje_get_setting( 'post_type_rest_endpoint', 'news' );

$args = apply_filters(
	'nisje_news_post_type_args', [
		'labels'                => [
			'name'          => esc_html__( 'News', 'nisje-news' ),
			'singular_name' => esc_html__( 'News', 'nisje-news' ),
		],
		'public'                => true,
		'publicly_queryable'    => true,
		'exclude_from_search'   => false,
		'show_in_admin_bar'     => false,
		'show_in_nav_menus'     => false,
		'can_export'            => false,
		'show_ui'               => true,
		'query_var'             => false,
		'has_archive'           => false,
		'rewrite'               => [
			'slug'       => 'news/%post_id%',
			'with_front' => false,
		],
		'capability_type'       => $cap,
		'capabilities'          => [
			'create_posts'     => "create_{$cap}s",
			'delete_posts'     => "delete_{$cap}s",
			'upload_files_cpt' => "upload_files_{$cap}",
		],
		'map_meta_cap'          => true,
		'hierarchical'          => false,
		'menu_position'         => null,
		'menu_icon'             => 'dashicons-media-text',
		'supports'              => [
			'author',
			'title',
			'revisions',
			'editor',
			'thumbnail',
			'comments',
			'excerpt',
		],
		'show_in_rest'          => true,
		'rest_base'             => $rest_endpoint,
		'rest_controller_class' => 'WP_REST_Posts_Controller',
	]
);

register_post_type( $post_type_name, $args ); // phpcs:ignore

==> nisje-wp-plugin-news-9.4.0.zip: news/post-types/post-type-news.php <==
<?php
/**
 * Setup News Post Type
 *
 * @package Nisje
 */

defined( 'ABSPATH' ) || die( 'Shame on you' );

$cap            = nisje_get_setting( 'capability_key', 'news' );
$post_type_name = nisje_get_setting( 'post_type_name', 'news' );
$rest_endpoint  = nisje_get_setting( 'post_type_rest_endpoint', 'news' );

$args = apply_filters(
	'nisje_news_post_type_args', [
		'labels'                => [
			'name'          => esc_html__( 'News', 'nisje' ),
			'singular_name' => esc_html__( 'News', 'nisje' ),
		],
		'public'                => true,
		'publicly_queryable'    => true,
		'exclude_from_search'   => false,
		'show_in_admin_bar'     => false,
		'show_in_nav_menus'     => false,
		'can_export'            => false,
		'show_ui'               => true,
		'query_var'             => false,
		'has_archive'           => false,
		'rewrite'               => [
			'slug'       => 'news/%post_id%',
			'with_front' => false,
		],
		'capability_type'       => $cap,
		'capabilities'          => [
			'create_posts'     => "create_{$cap}s",
			'delete_posts'     => "delete_{$cap}s",
			'upload_files_cpt' => "upload_files_{$cap}",
		],
		'map_meta_cap'          => true,
		'hierarchical'          => false,
		'menu_position'         => null,
		'menu_icon'             => 'dashicons-media-text',
		'supports'              => [
			'author',
			'title',
			'revisions',
			'editor',
			'thumbnail',
			'comments',
			'excerpt',
		],
		'show_in_rest'          => true,
		'rest_base'             => $rest_endpoint,
		'rest_controller_class' => 'WP_REST_Posts_Controller',
	]
);

register_post_type( $post_type_name, $args ); // phpcs:ignore
